<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="pt_BR">
<context>
    <name>QStarDict::CSSEdit</name>
    <message>
        <location filename="../cssedit.ui" line="16"/>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="30"/>
        <source>Element</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="37"/>
        <source>Foreground</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="44"/>
        <source>Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="51"/>
        <source>Select element</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="68"/>
        <source>Click to select color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="71"/>
        <source>#000000</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="78"/>
        <source>Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="85"/>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="92"/>
        <source>Select font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="99"/>
        <source>Select font size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="102"/>
        <source>pt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="127"/>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="130"/>
        <source>B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="147"/>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="150"/>
        <source>I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="167"/>
        <source>Underline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="170"/>
        <source>U</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QStarDict::DictBrowser</name>
    <message>
        <location filename="../dictbrowser.cpp" line="74"/>
        <source>The word &lt;b&gt;%1&lt;/b&gt; is not found.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QStarDict::DictWidget</name>
    <message>
        <location filename="../dictwidget.cpp" line="114"/>
        <source>Save translation</source>
        <translation type="unfinished">Salvar tradução</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="135"/>
        <source>HTML files (*.html, *.htm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="124"/>
        <source>Text files (*.txt)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="130"/>
        <source>Error</source>
        <translation type="unfinished">Erro</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="131"/>
        <source>Cannot save translation as %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="75"/>
        <source>Go to &amp;previous translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="80"/>
        <source>Go to &amp;next translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="85"/>
        <source>&amp;Save to file</source>
        <translation type="unfinished">&amp;Salvar para arquivo</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="91"/>
        <source>Speak &amp;word</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="88"/>
        <source>Prin&amp;t translation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QStarDict::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="118"/>
        <source>About QStarDict</source>
        <translation type="unfinished">Sobre QStarDict</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="119"/>
        <source>&lt;b&gt;QStarDict %1 &lt;/b&gt; - Qt version of StarDict&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="121"/>
        <source>Copyright (C) 2007-2009 Alexander Rodin &lt;a href=&quot;http://qstardict.ylsoftware.com&quot;&gt;http://qstardict.ylsoftware.com&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="13"/>
        <source>QStarDict</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="192"/>
        <source>%1 - QStarDict</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="38"/>
        <source>Clear the search box</source>
        <translation type="unfinished">Limpar caixa de Busca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="41"/>
        <source>Clear</source>
        <translation type="unfinished">Limpar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>Fuzzy query</source>
        <translation type="unfinished">Fuzzy Consulta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="61"/>
        <source>Search</source>
        <translation type="unfinished">Buscar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="87"/>
        <source>Words list</source>
        <translation type="unfinished">Lista de Palavras</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Arquivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="123"/>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="131"/>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Configurações</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="146"/>
        <source>&amp;Quit</source>
        <translation type="unfinished">&amp;Sair</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="149"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished">Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <source>&amp;About</source>
        <translation type="unfinished">&amp;Sobre</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="159"/>
        <source>About &amp;Qt</source>
        <translation type="unfinished">Sobre Qt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>&amp;Configure QStarDict</source>
        <translation type="unfinished">&amp;Configurar QStarDict</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <source>&amp;Scan</source>
        <translation type="unfinished">&amp;Busca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>QStarDict &amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="188"/>
        <source>F1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QStarDict::SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="69"/>
        <source>Enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="69"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="69"/>
        <source>Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="273"/>
        <source>Information about dictionary &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="291"/>
        <source>&lt;b&gt;Name:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="275"/>
        <source>&lt;b&gt;Plugin:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="277"/>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="295"/>
        <source>&lt;b&gt;Description:&lt;/b&gt; %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="290"/>
        <source>Information about %1 plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="292"/>
        <source>&lt;b&gt;Version:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="293"/>
        <source>&lt;b&gt;Authors:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="293"/>
        <source>&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="294"/>
        <source>&lt;b&gt;Can search similar words:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="294"/>
        <source>yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="294"/>
        <source>no</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>QStarDict Settings</source>
        <translation type="unfinished">Configurações QStarDict</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="161"/>
        <source>Show information about dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Global settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>Instant search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="73"/>
        <source>Pronounce words using this command:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="80"/>
        <source>Enter cmd for the speaching program.&lt;br&gt;If cmd contains &quot;%s&quot; it will be replaced to word, else word will be writen to stdin of speech process.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="109"/>
        <source>Dictionaries</source>
        <translation type="unfinished">Dicionários</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="133"/>
        <source>Move up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="136"/>
        <source>Up</source>
        <translation type="unfinished">Cima</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="147"/>
        <source>Move down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="150"/>
        <source>Down</source>
        <translation type="unfinished">Baixo</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="164"/>
        <source>Show info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="199"/>
        <source>Plugins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="226"/>
        <source>Show information about plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="229"/>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="240"/>
        <source>Configure plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="243"/>
        <source>Configure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="273"/>
        <source>Popup window</source>
        <translation type="unfinished">Janela Popup</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="285"/>
        <source>Behavior</source>
        <translation type="unfinished">Comportamento</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="305"/>
        <source>Pronounce the word</source>
        <translation type="unfinished">Pronúciar esta palavra</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="322"/>
        <source>Timeout before hide after mouse over</source>
        <translation type="unfinished">Esperar antes esconder depois de passar o mouse sobre</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="329"/>
        <source>Don&apos;t hide</source>
        <translation type="unfinished">Não Esconder</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="332"/>
        <source> sec</source>
        <translation type="unfinished">seg</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="367"/>
        <source>Show only if modifier pressed</source>
        <translation type="unfinished">Mostrar somente com modificador pressionando</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="378"/>
        <source>Alt</source>
        <translation type="unfinished">Alt</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="383"/>
        <source>Control</source>
        <translation type="unfinished">Control</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="388"/>
        <source>Shift</source>
        <translation type="unfinished">Shift</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="393"/>
        <source>Win</source>
        <translation type="unfinished">Win</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="403"/>
        <source>Scan selection</source>
        <translation type="unfinished">Buscar Seleção</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="413"/>
        <source>Show if word not found</source>
        <translation type="unfinished">Mostrar as palavras não encontradas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="548"/>
        <source>Apperance</source>
        <translation type="unfinished">Aparencia</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="443"/>
        <source>Opacity</source>
        <translation type="unfinished"><byte value="x9"/>
Opacidade</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="450"/>
        <source>%</source>
        <translation type="unfinished">%</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="479"/>
        <source>Default width</source>
        <translation type="unfinished"><byte value="x9"/>
Largura padrão</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="509"/>
        <source>Default height</source>
        <translation type="unfinished">Altura Padrão</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="276"/>
        <source>&lt;b&gt;Author:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="277"/>
        <source>&lt;b&gt;Words count:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="115"/>
        <source>All translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="116"/>
        <source>Dictionary name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="117"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="118"/>
        <source>Explanation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="119"/>
        <source>Abbreviation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="120"/>
        <source>Example</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="121"/>
        <source>Transcription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Use system tray</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QStarDict::TrayIcon</name>
    <message>
        <location filename="../trayicon.cpp" line="37"/>
        <source>QStarDict</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="38"/>
        <source>&amp;Scan</source>
        <translation type="unfinished">&amp;Busca</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="48"/>
        <source>&amp;Configure QStarDict</source>
        <translation type="unfinished">&amp;Configurar QStarDict</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="51"/>
        <source>&amp;Quit</source>
        <translation type="unfinished">&amp;Sair</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="92"/>
        <source>QStarDict: scanning is %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="92"/>
        <source>enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="92"/>
        <source>disabled</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
